"use strict";
/**
 * Http Status Codes
 *
 * HTTP response status codes indicate whether a specific HTTP request has been successfully completed.
 * Responses are grouped in five classes:
 *
 * Informational responses [100–199]
 * Successful responses [200–299]
 * Redirection messages [300–399]
 * Client error responses [400–499]
 * Server error responses [500–599]
 *
 * Source {@link https://developer.mozilla.org/en-US/docs/Web/HTTP/Status}
 *
 * @export
 * @enum {number}
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.StatusCode = void 0;
var StatusCode;
(function (StatusCode) {
    /**
     * @description This interim response indicates that the client should continue the request or ignore the response if the request is already finished.
     */
    StatusCode[StatusCode["CONTINUE"] = 100] = "CONTINUE";
    /**
     * @description This code is sent in response to an Upgrade request header from the client and indicates the protocol the server is switching to.
     */
    StatusCode[StatusCode["SWITCHING_PROTOCOLS"] = 101] = "SWITCHING_PROTOCOLS";
    /**
     * @description This code indicates that the server has received and is processing the request, but no response is available yet.
     */
    StatusCode[StatusCode["PROCESSING"] = 102] = "PROCESSING";
    /**
     * @description This status code is primarily intended to be used with the Link header, letting the user agent start preloading resources while the server prepares a response.
     */
    StatusCode[StatusCode["EARLY_HINTS"] = 103] = "EARLY_HINTS";
    /**
     * @description The request succeeded. The result meaning of "success" depends on the HTTP method
     */
    StatusCode[StatusCode["OK"] = 200] = "OK";
    /**
     * @description The request succeeded, and a new resource was created as a result. This is typically the response sent after POST requests, or some PUT requests.
     */
    StatusCode[StatusCode["CREATED"] = 201] = "CREATED";
    /**
     * @description The request has been received but not yet acted upon. It is noncommittal, since there is no way in HTTP to later send an asynchronous response indicating the outcome of the request. It is intended for cases where another process or server handles the request, or for batch processing.
     */
    StatusCode[StatusCode["ACCEPTED"] = 202] = "ACCEPTED";
    /**
     * @description This response code means the returned metadata is not exactly the same as is available from the origin server, but is collected from a local or a third-party copy. This is mostly used for mirrors or backups of another resource. Except for that specific case, the 200 OK response is preferred to this status.
     */
    StatusCode[StatusCode["NON_AUTHORITATIVE_INFORMATION"] = 203] = "NON_AUTHORITATIVE_INFORMATION";
    /**
     * @description There is no content to send for this request, but the headers may be useful. The user agent may update its cached headers for this resource with the new ones.
     */
    StatusCode[StatusCode["NO_CONTENT"] = 204] = "NO_CONTENT";
    /**
     * @description Tells the user agent to reset the document which sent this request.
     */
    StatusCode[StatusCode["RESET_CONTENT"] = 205] = "RESET_CONTENT";
    /**
     * @description This response code is used when the Range header is sent from the client to request only part of a resource.
     */
    StatusCode[StatusCode["PARTIAL_CONTENT"] = 206] = "PARTIAL_CONTENT";
    /**
     * @description Conveys information about multiple resources, for situations where multiple status codes might be appropriate.
     */
    StatusCode[StatusCode["MULTI_STATUS"] = 207] = "MULTI_STATUS";
    /**
     * @description Used inside a "<dav:propstat>" response element to avoid repeatedly enumerating the internal members of multiple bindings to the same collection.
     */
    StatusCode[StatusCode["ALREADY_REPORTED"] = 208] = "ALREADY_REPORTED";
    /**
     * @description The server has fulfilled a GET request for the resource, and the response is a representation of the result of one or more instance-manipulations applied to the current instance.
     */
    StatusCode[StatusCode["IM_USED"] = 226] = "IM_USED";
    /**
     * @description The request has more than one possible response.
     */
    StatusCode[StatusCode["MULTIPLE_CHOICES"] = 300] = "MULTIPLE_CHOICES";
    /**
     * @description The URL of the requested resource has been changed permanently. The new URL is given in the response.
     */
    StatusCode[StatusCode["MOVED_PERMANENTLY"] = 301] = "MOVED_PERMANENTLY";
    /**
     * @description This response code means that the URI of requested resource has been changed temporarily. Further changes in the URI might be made in the future. Therefore, this same URI should be used by the client in future requests.
     */
    StatusCode[StatusCode["FOUND"] = 302] = "FOUND";
    /**
     * @description The server sent this response to direct the client to get the requested resource at another URI with a GET request.
     */
    StatusCode[StatusCode["SEE_OTHER"] = 303] = "SEE_OTHER";
    /**
     * @description This is used for caching purposes. It tells the client that the response has not been modified, so the client can continue to use the same cached version of the response.
     */
    StatusCode[StatusCode["NOT_MODIFIED"] = 304] = "NOT_MODIFIED";
    /**
     * @description The server sends this response to direct the client to get the requested resource at another URI with same method that was used in the prior request.
     */
    StatusCode[StatusCode["TEMPORARY_REDIRECT"] = 307] = "TEMPORARY_REDIRECT";
    /**
     * @description This means that the resource is now permanently located at another URI, specified by the Location: HTTP Response header. This has the same semantics as the 301 Moved Permanently HTTP response code, with the exception that the user agent must not change the HTTP method used: if a POST was used in the first request, a POST must be used in the second request.
     */
    StatusCode[StatusCode["PERMANENT_REDIRECT"] = 308] = "PERMANENT_REDIRECT";
    /**
     * @description The server cannot or will not process the request due to something that is perceived to be a client error (e.g., malformed request syntax, invalid request message framing, or deceptive request routing).
     */
    StatusCode[StatusCode["BAD_REQUEST"] = 400] = "BAD_REQUEST";
    /**
     * @description Although the HTTP standard specifies "unauthorized", semantically this response means "unauthenticated". That is, the client must authenticate itself to get the requested response.
     */
    StatusCode[StatusCode["UNAUTHORIZED"] = 401] = "UNAUTHORIZED";
    /**
     * @description This response code is reserved for future use. The initial aim for creating this code was using it for digital payment systems, however this status code is used very rarely and no standard convention exists.
     */
    StatusCode[StatusCode["PAYMENT_REQUIRED"] = 402] = "PAYMENT_REQUIRED";
    /**
     * @description The client does not have access rights to the content; that is, it is unauthorized, so the server is refusing to give the requested resource. Unlike 401 Unauthorized, the client's identity is known to the server.
     */
    StatusCode[StatusCode["FORBIDDEN"] = 403] = "FORBIDDEN";
    /**
     * @description The server can not find the requested resource. In the browser, this means the URL is not recognized. In an API, this can also mean that the endpoint is valid but the resource itself does not exist. Servers may also send this response instead of 403 Forbidden to hide the existence of a resource from an unauthorized client. This response code is probably the most well known due to its frequent occurrence on the web.
     */
    StatusCode[StatusCode["NOT_FOUND"] = 404] = "NOT_FOUND";
    /**
     * @description The request method is known by the server but is not supported by the target resource. For example, an API may not allow calling DELETE to remove a resource.
     */
    StatusCode[StatusCode["METHOD_NOT_ALLOWED"] = 405] = "METHOD_NOT_ALLOWED";
    /**
     * @description This response is sent when the web server, after performing server-driven content negotiation, doesn't find any content that conforms to the criteria given by the user agent.
     */
    StatusCode[StatusCode["NOT_ACCEPTABLE"] = 406] = "NOT_ACCEPTABLE";
    /**
     * @description This is similar to 401 Unauthorized but authentication is needed to be done by a proxy.
     */
    StatusCode[StatusCode["PROXY_AUTHENTICATION_REQUIRED"] = 407] = "PROXY_AUTHENTICATION_REQUIRED";
    /**
     * @description This response is sent on an idle connection by some servers, even without any previous request by the client. It means that the server would like to shut down this unused connection.
     */
    StatusCode[StatusCode["REQUEST_TIMEOUT"] = 408] = "REQUEST_TIMEOUT";
    /**
     * @description This response is sent when a request conflicts with the current state of the server.
     */
    StatusCode[StatusCode["CONFLICT"] = 409] = "CONFLICT";
    /**
     * @description This response is sent when the requested content has been permanently deleted from server, with no forwarding address. Clients are expected to remove their caches and links to the resource. The HTTP specification intends this status code to be used for "limited-time, promotional services". APIs should not feel compelled to indicate resources that have been deleted with this status code.
     */
    StatusCode[StatusCode["GONE"] = 410] = "GONE";
    /**
     * @description Server rejected the request because the Content-Length header field is not defined and the server requires it.
     */
    StatusCode[StatusCode["LENGTH_REQUIRED"] = 411] = "LENGTH_REQUIRED";
    /**
     * @description The client has indicated preconditions in its headers which the server does not meet.
     */
    StatusCode[StatusCode["PRECONDITION_FAILED"] = 412] = "PRECONDITION_FAILED";
    /**
     * @description Request entity is larger than limits defined by server. The server might close the connection or return an Retry-After header field.
     */
    StatusCode[StatusCode["PAYLOAD_TOO_LARGE"] = 413] = "PAYLOAD_TOO_LARGE";
    /**
     * @description The URI requested by the client is longer than the server is willing to interpret.
     */
    StatusCode[StatusCode["URI_TOO_LONG"] = 414] = "URI_TOO_LONG";
    /**
     * @description The media format of the requested data is not supported by the server, so the server is rejecting the request.
     */
    StatusCode[StatusCode["UNSUPPORTED_MEDIA_TYPE"] = 415] = "UNSUPPORTED_MEDIA_TYPE";
    /**
     * @description The range specified by the Range header field in the request cannot be fulfilled. It's possible that the range is outside the size of the target URI's data.
     */
    StatusCode[StatusCode["RANGE_NOT_SATISFIABLE"] = 416] = "RANGE_NOT_SATISFIABLE";
    /**
     * @description This response code means the expectation indicated by the Expect request header field cannot be met by the server.
     */
    StatusCode[StatusCode["EXPECTATION_FAILED"] = 417] = "EXPECTATION_FAILED";
    /**
     * @description The server refuses the attempt to brew coffee with a teapot.
     */
    StatusCode[StatusCode["IM_A_TEAPOT"] = 418] = "IM_A_TEAPOT";
    /**
     * @description The request was directed at a server that is not able to produce a response. This can be sent by a server that is not configured to produce responses for the combination of scheme and authority that are included in the request URI.
     */
    StatusCode[StatusCode["MISDIRECTED_REQUEST"] = 421] = "MISDIRECTED_REQUEST";
    /**
     * @description The request was well-formed but was unable to be followed due to semantic errors.
     */
    StatusCode[StatusCode["UNPROCESSABLE_ENTITY"] = 422] = "UNPROCESSABLE_ENTITY";
    /**
     * @description The resource that is being accessed is locked.
     */
    StatusCode[StatusCode["LOCKED"] = 423] = "LOCKED";
    /**
     * @description The request failed due to failure of a previous request.
     */
    StatusCode[StatusCode["FAILED_DEPENDENCY"] = 424] = "FAILED_DEPENDENCY";
    /**
     * @description Indicates that the server is unwilling to risk processing a request that might be replayed.
     */
    StatusCode[StatusCode["TOO_EARLY"] = 425] = "TOO_EARLY";
    /**
     * @description The server refuses to perform the request using the current protocol but might be willing to do so after the client upgrades to a different protocol. The server sends an Upgrade header in a 426 response to indicate the required protocol(s).
     */
    StatusCode[StatusCode["UPGRADE_REQUIRED"] = 426] = "UPGRADE_REQUIRED";
    /**
     * @description The origin server requires the request to be conditional. This response is intended to prevent the 'lost update' problem, where a client GETs a resource's state, modifies it and PUTs it back to the server, when meanwhile a third party has modified the state on the server, leading to a conflict.
     */
    StatusCode[StatusCode["PRECONDITION_REQUIRED"] = 428] = "PRECONDITION_REQUIRED";
    /**
     * @description The user has sent too many requests in a given amount of time ("rate limiting").
     */
    StatusCode[StatusCode["TOO_MANY_REQUESTS"] = 429] = "TOO_MANY_REQUESTS";
    /**
     * @description The server is unwilling to process the request because its header fields are too large. The request may be resubmitted after reducing the size of the request header fields.
     */
    StatusCode[StatusCode["REQUEST_HEADER_FIELDS_TOO_LARGE"] = 431] = "REQUEST_HEADER_FIELDS_TOO_LARGE";
    /**
     * @description The user agent requested a resource that cannot legally be provided, such as a web page censored by a government.
     */
    StatusCode[StatusCode["UNAVAILABLE_FOR_LEGAL_REASONS"] = 451] = "UNAVAILABLE_FOR_LEGAL_REASONS";
    /**
     * @description This error response means that the server, while working as a gateway to get a response needed to handle the request, got an invalid response.
     */
    StatusCode[StatusCode["INTERNAL_SERVER_ERROR"] = 500] = "INTERNAL_SERVER_ERROR";
    /**
     * @description The request method is not supported by the server and cannot be handled. The only methods that servers are required to support (and therefore that must not return this code) are GET and HEAD.
     */
    StatusCode[StatusCode["NOT_IMPLEMENTED"] = 501] = "NOT_IMPLEMENTED";
    /**
     * @description This error response means that the server, while working as a gateway to get a response needed to handle the request, got an invalid response.
     */
    StatusCode[StatusCode["BAD_GATEWAY"] = 502] = "BAD_GATEWAY";
    /**
     * @description The server is not ready to handle the request. Common causes are a server that is down for maintenance or that is overloaded. Note that together with this response, a user-friendly page explaining the problem should be sent.
     */
    StatusCode[StatusCode["SERVICE_UNAVAILABLE"] = 503] = "SERVICE_UNAVAILABLE";
    /**
     * @description This error response is given when the server is acting as a gateway and cannot get a response in time.
     */
    StatusCode[StatusCode["GATEWAY_TIMEOUT"] = 504] = "GATEWAY_TIMEOUT";
    /**
     * @description The HTTP version used in the request is not supported by the server.
     */
    StatusCode[StatusCode["HTTP_VERSION_NOT_SUPPORTED"] = 505] = "HTTP_VERSION_NOT_SUPPORTED";
    /**
     * @description The server has an internal configuration error: the chosen variant resource is configured to engage in transparent content negotiation itself, and is therefore not a proper end point in the negotiation process.
     */
    StatusCode[StatusCode["VARIANT_ALSO_NEGOTIATES"] = 506] = "VARIANT_ALSO_NEGOTIATES";
    /**
     * @description The method could not be performed on the resource because the server is unable to store the representation needed to successfully complete the request.
     */
    StatusCode[StatusCode["INSUFFICIENT_STORAGE"] = 507] = "INSUFFICIENT_STORAGE";
    /**
     * @description The server detected an infinite loop while processing the request.
     */
    StatusCode[StatusCode["LOOP_DETECTED"] = 508] = "LOOP_DETECTED";
    /**
     * @description Further extensions to the request are required for the server to fulfill it.
     */
    StatusCode[StatusCode["NOT_EXTENDED"] = 510] = "NOT_EXTENDED";
    /**
     * @description Indicates that the client needs to authenticate to gain network access.
     */
    StatusCode[StatusCode["NETWORK_AUTHENTICATION_REQUIRED"] = 511] = "NETWORK_AUTHENTICATION_REQUIRED";
})(StatusCode = exports.StatusCode || (exports.StatusCode = {}));
